@@ -2,8 +2,8 @@ from __future__ import unicode_literals
 
 from .base import Base
 from .entity import Entity
-from trustar2.base import fluent
-from trustar2.trustar_enums import ObservableTypes, MaxValues
+from trustar2.base import fluent, typename
+from trustar2.trustar_enums import ObservableTypes, MaxValues, IndicatorEnum
 
 
 @fluent
@@ -26,6 +26,11 @@ class Indicator(Base):
         self.related_observables = []
         self.tags = []
 
+
+    def __repr__(self):
+        return "{}(value={}, type={})".format(typename(self), self.observable.value, self.observable.type)
+    
+
     def set_related_observables(self, related_obs):
         if isinstance(related_obs, list):
             self.related_observables += related_obs
@@ -96,9 +101,20 @@ class Indicator(Base):
     def serialize(self):
         serialized = {}
         serialized.update(self.observable.serialize())
-        serialized.update({"attributes": [attr.serialize() for attr in self.attributes] if len(self.attributes) else []})
-        serialized.update({"relatedObservables": [attr.serialize() for attr in self.related_observables] if len(self.related_observables) else []})
-        serialized.update({"tags": self.tags})
+
+        serialized.update({
+            IndicatorEnum.ATTRIBUTES.value: [attr.serialize() for attr in self.attributes] 
+            if len(self.attributes) else []
+        })
+
+        serialized.update({
+            IndicatorEnum.RELATED_OBSERVABLES.value: [
+                attr.serialize() 
+                for attr in self.related_observables
+            ] 
+            if len(self.related_observables) else []
+        })
+        serialized.update({IndicatorEnum.TAGS.value: self.tags})
         return serialized
 
 
@@ -114,8 +130,8 @@ class Indicator(Base):
 
     @classmethod
     def from_dict(cls, ioc_dict):
-        observable = ioc_dict.pop("observable")
-        indicator = cls(observable.get("type"), observable.get("value"))
+        observable = ioc_dict.pop(IndicatorEnum.OBSERVABLE.value)
+        indicator = cls(observable.get(IndicatorEnum.TYPE.value), observable.get(IndicatorEnum.VALUE.value))
         
         for field, value in ioc_dict.items():
             method_name = cls.FIELD_METHOD_MAPPING.get(field)
