@@ -42,7 +42,7 @@ class ObservableTypes(TSEnum):
 
 class AttributeTypes(TSEnum):
     
-    CORA_MALWARE = "CORA_MALWARE"
+    CARO_MALWARE = "CARO_MALWARE"
     CVE = "CVE"
     MALWARE = "MALWARE"
     MITRE_TACTIC = "MITRE_TACTIC"
@@ -66,8 +66,10 @@ class MaxValues(TSEnum):
 
 class WorkflowDestinations(TSEnum):
 
-    QRADAR = "QRADAR"
     ENCLAVE = "ENCLAVE"
+    SPLUNK_SOAR = "SPLUNK_SOAR"
+    SPLUNK = "SPLUNK"
+    SPLUNK_ES = "SPLUNK_ES"
     UNKNOWN = "UNKNOWN"
 
 
